@@ -16,7 +16,7 @@ use GD::Polygon;
 
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
 
-$VERSION = '2.60';
+$VERSION = '2.61';
 our $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -65,28 +65,6 @@ $VERSION = eval $VERSION;
 # documentation error
 *GD::Polygon::delete = \&GD::Polygon::deletePt;
 
-sub AUTOLOAD {
-    # This AUTOLOAD is used to 'autoload' constants from the constant()
-    # XS function.  If a constant is not found then control is passed
-    # to the AUTOLOAD in AutoLoader.
-
-    my($constname);
-    ($constname = $AUTOLOAD) =~ s/.*:://;
-    my $val = constant($constname);
-    if ($! != 0) {
-	if ($! =~ /Invalid/) {
-	    $AutoLoader::AUTOLOAD = $AUTOLOAD;
-	    goto &AutoLoader::AUTOLOAD;
-	}
-	else {
-	    my($pack,$file,$line) = caller;
-	    die "Your vendor has not defined GD macro $pack\:\:$constname, used at $file line $line.\n";
-	}
-    }
-    eval "sub $AUTOLOAD { $val }";
-    goto &$AUTOLOAD;
-}
-
 bootstrap GD;
 
 
@@ -609,8 +587,8 @@ If no colors are allocated, then this function returns -1.
 
 Example:
 
-	$white = $myImage->colorAllocate(0,0,0); #background color
-	$black = $myImage->colorAllocate(255,255,255);
+	$black = $myImage->colorAllocate(0,0,0); #background color
+	$white = $myImage->colorAllocate(255,255,255);
 	$peachpuff = $myImage->colorAllocate(255,218,185);
 
 =item B<$index = $image-E<gt>colorAllocateAlpha(reg,green,blue,alpha)>
@@ -1232,11 +1210,43 @@ output image instead, which guarantees the highest output quality.
 Both the dithering (0/1, default=0) and maximum number of colors used
 (<=256, default = gdMaxColors) can be specified.
 
+=item B<$image = $sourceImage-E<gt>createPaletteFromTrueColor([$dither], [$colors])>
+
+Creates a new palette image from a truecolor image. Same as above, but
+returns a new image.
+
+Don't use these function -- write real truecolor PNGs and JPEGs. The
+disk space gain of conversion to palette is not great (for small
+images it can be negative) and the quality loss is ugly.
+
+=item B<$error = $image-E<gt>colorMatch($otherimage)>
+
+Bring the palette colors in $otherimage to be closer to truecolor $image.
+A negative return value is a failure.
+
+  -1 image must be True Color
+  -2 otherimage must be indexed
+  -3 the images are meant to be the same dimensions
+  -4 At least 1 color in otherimage must be allocated
+
+This method is only available with libgd >= 2.1.0
+
+=item B<$image = $sourceImage-E<gt>neuQuant($maxcolor=256,$samplefactor=5)>
+
+Creates a new palette image from a truecolor image.
+
+  samplefactor	The quantization precision between 1 (highest quality) and 10 (fastest).
+  maxcolor	The number of desired palette entries.
+
+This is the same as createPaletteFromTrueColor with the
+quantization method GD_QUANT_NEUQUANT. This does not support dithering.
+This method is only available with libgd >= 2.1.0
+
 =back
 
 =head2 Image Transformation Commands
 
-Gd also provides some common image transformations:
+Gd provides these simple image transformations, non-interpolated.
 
 =over 4
 
@@ -1268,6 +1278,129 @@ modify the image in place.
 
 =back
 
+=head2 Image Interpolation Methods
+
+Since libgd 2.1.0 there are better transformation methods, with
+these interpolation methods:
+
+  GD_BELL		 - Bell
+  GD_BESSEL		 - Bessel
+  GD_BILINEAR_FIXED 	 - fixed point bilinear
+  GD_BICUBIC 		 - Bicubic
+  GD_BICUBIC_FIXED 	 - fixed point bicubic integer
+  GD_BLACKMAN		 - Blackman
+  GD_BOX		 - Box
+  GD_BSPLINE		 - BSpline
+  GD_CATMULLROM		 - Catmullrom
+  GD_GAUSSIAN		 - Gaussian
+  GD_GENERALIZED_CUBIC   - Generalized cubic
+  GD_HERMITE		 - Hermite
+  GD_HAMMING		 - Hamming
+  GD_HANNING		 - Hannig
+  GD_MITCHELL		 - Mitchell
+  GD_NEAREST_NEIGHBOUR   - Nearest neighbour interpolation
+  GD_POWER		 - Power
+  GD_QUADRATIC		 - Quadratic
+  GD_SINC		 - Sinc
+  GD_TRIANGLE		 - Triangle
+  GD_WEIGHTED4		 - 4 pixels weighted bilinear interpolation
+  GD_LINEAR              - bilinear interpolation
+
+=over 4
+
+=item B<$image-E<gt>interpolationMethod( [$method] )>
+
+Gets or sets the interpolation methods for all subsequent interpolations.
+See above for the valid values.
+Only available since libgd 2.2.0
+
+=item B<$image-E<gt>copyScaleInterpolated( width, height )>
+
+Returns a copy, using interpolation.
+
+=item B<$image-E<gt>copyRotateInterpolated( angle, bgcolor )>
+
+Returns a copy, using interpolation.
+
+=back
+
+=head2 Image Filter Commands
+
+Gd also provides some common image filters, they modify the image in
+place and return TRUE if modified or FALSE if not.
+Most of them need libgd >= 2.1.0, with older versions those functions are undefined.
+
+=over 4
+
+=item B<$ok = $image-E<gt>scatter($sub, $plus)>
+
+if $sub and $plus are 0, nothing is changed, TRUE is returned.
+if $sub >= $plus, nothing is changed, FALSE is returned.
+else random pixels are changed.
+
+=item B<$ok = $image-E<gt>scatterColor($sub, $plus, @colors)>
+
+Similar to scatter, but using the given array of colors,
+i.e. palette indices.
+
+=item B<$ok = $image-E<gt>pixelate($blocksize, $mode)>
+
+if $blocksize <= 0, nothing is changed, FALSE is returned.
+if $blocksize == 1, nothing is changed, TRUE is returned.
+else the following modes are observed:
+  GD_PIXELATE_UPPERLEFT
+  GD_PIXELATE_AVERAGE
+
+=item B<$ok = $image-E<gt>negate()>
+
+=item B<$ok = $image-E<gt>grayscale()>
+
+=item B<$ok = $image-E<gt>brightness($add)>
+
+$add: -255..255
+
+=item B<$ok = $image-E<gt>contrast($contrast)>
+
+$contrast: a double value. The contrast adjustment value. Negative
+values increase, postive values decrease the contrast. The larger
+the absolute value, the stronger the effect.
+
+=item B<$ok = $image-E<gt>color($red,$green,$blue,$alpha)>
+
+Change channel values of an image.
+
+  $red   - The value to add to the red channel of all pixels.
+  $green - The value to add to the green channel of all pixels.
+  $blue  - The value to add to the blue channel of all pixels.
+  $alpha - The value to add to the alpha channel of all pixels.
+
+=item B<$ok = $image-E<gt>selectiveBlur()>
+
+=item B<$ok = $image-E<gt>edgeDetectQuick()>
+
+=item B<$ok = $image-E<gt>gaussianBlur()>
+
+=item B<$ok = $image-E<gt>emboss()>
+
+=item B<$ok = $image-E<gt>meanRemoval()>
+
+=item B<$ok = $image-E<gt>smooth($weight)>
+
+=item B<$image = $sourceImage-E<gt>copyGaussianBlurred($radius, $sigma)>
+
+$radius: int, the blur radius (*not* diameter--range is 2*radius + 1)
+a radius, not a diameter so a radius of 2 (for example) will blur
+across a region 5 pixels across (2 to the center, 1 for the center
+itself and another 2 to the other edge).
+
+$sigma: the sigma value or a value <= 0.0 to use the computed default.
+represents the "fatness" of the curve (lower == fatter).
+
+The result is always truecolor.
+
+=back
+
+
 =head2 Character and String Drawing
 
 GD allows you to draw characters and strings, either in normal
@@ -1804,6 +1937,10 @@ These return the width and height of the font.
 
 =over
 
+=item GD::VERSION
+
+Returns a number of the VERSION, like 2.0204, 2.0033 or 2.01.
+
 =item GD::VERSION_STRING
 
 Returns the string of the libgd VERSION, like "2.2.4".
